@@ -42,9 +42,17 @@ from .._impl import (
     scout_chartdefinition_api_FrequencyChartDefinitionV1 as FrequencyChartDefinitionV1,
     scout_chartdefinition_api_FrequencyChartDefinitionVisitor as FrequencyChartDefinitionVisitor,
     scout_chartdefinition_api_FrequencyPlot as FrequencyPlot,
+    scout_chartdefinition_api_FrequencyPlotType as FrequencyPlotType,
+    scout_chartdefinition_api_FrequencyPlotTypeFft as FrequencyPlotTypeFft,
+    scout_chartdefinition_api_FrequencyPlotTypePeriodogram as FrequencyPlotTypePeriodogram,
+    scout_chartdefinition_api_FrequencyPlotTypeVisitor as FrequencyPlotTypeVisitor,
+    scout_chartdefinition_api_Geo3dCustomModel as Geo3dCustomModel,
+    scout_chartdefinition_api_Geo3dDefaultModel as Geo3dDefaultModel,
     scout_chartdefinition_api_Geo3dDefinition as Geo3dDefinition,
     scout_chartdefinition_api_Geo3dDefinitionV1 as Geo3dDefinitionV1,
     scout_chartdefinition_api_Geo3dDefinitionVisitor as Geo3dDefinitionVisitor,
+    scout_chartdefinition_api_Geo3dModel as Geo3dModel,
+    scout_chartdefinition_api_Geo3dModelVisitor as Geo3dModelVisitor,
     scout_chartdefinition_api_Geo3dOrientation as Geo3dOrientation,
     scout_chartdefinition_api_Geo3dOrientationPrincipalAxes as Geo3dOrientationPrincipalAxes,
     scout_chartdefinition_api_Geo3dOrientationVisitor as Geo3dOrientationVisitor,
@@ -124,7 +132,10 @@ from .._impl import (
     scout_chartdefinition_api_RangeValueVisualisationVisitor as RangeValueVisualisationVisitor,
     scout_chartdefinition_api_Scatter3dDecimationStrategy as Scatter3dDecimationStrategy,
     scout_chartdefinition_api_Scatter3dTraceComputeConfig as Scatter3dTraceComputeConfig,
+    scout_chartdefinition_api_StalenessCellConfig as StalenessCellConfig,
     scout_chartdefinition_api_StalenessConfiguration as StalenessConfiguration,
+    scout_chartdefinition_api_StalenessVisualisation as StalenessVisualisation,
+    scout_chartdefinition_api_StalenessVisualisationVisitor as StalenessVisualisationVisitor,
     scout_chartdefinition_api_Threshold as Threshold,
     scout_chartdefinition_api_ThresholdDisconnectedValues as ThresholdDisconnectedValues,
     scout_chartdefinition_api_ThresholdLineStyle as ThresholdLineStyle,
@@ -216,9 +227,17 @@ __all__ = [
     'FrequencyChartDefinitionVisitor',
     'FrequencyChartDefinitionV1',
     'FrequencyPlot',
+    'FrequencyPlotType',
+    'FrequencyPlotTypeVisitor',
+    'FrequencyPlotTypeFft',
+    'FrequencyPlotTypePeriodogram',
+    'Geo3dCustomModel',
+    'Geo3dDefaultModel',
     'Geo3dDefinition',
     'Geo3dDefinitionVisitor',
     'Geo3dDefinitionV1',
+    'Geo3dModel',
+    'Geo3dModelVisitor',
     'Geo3dOrientation',
     'Geo3dOrientationVisitor',
     'Geo3dOrientationPrincipalAxes',
@@ -298,7 +317,10 @@ __all__ = [
     'RangeValueVisualisationVisitor',
     'Scatter3dDecimationStrategy',
     'Scatter3dTraceComputeConfig',
+    'StalenessCellConfig',
     'StalenessConfiguration',
+    'StalenessVisualisation',
+    'StalenessVisualisationVisitor',
     'Threshold',
     'ThresholdDisconnectedValues',
     'ThresholdLineStyle',
