@@ -5,6 +5,7 @@ from .._impl import (
     scout_compute_api_AfterPersistenceWindow as AfterPersistenceWindow,
     scout_compute_api_AggregateEnumSeries as AggregateEnumSeries,
     scout_compute_api_AggregateNumericSeries as AggregateNumericSeries,
+    scout_compute_api_AggregateUnderRangesSeries as AggregateUnderRangesSeries,
     scout_compute_api_AllowNegativeValues as AllowNegativeValues,
     scout_compute_api_ApproximateThresholdOperator as ApproximateThresholdOperator,
     scout_compute_api_ApproximateThresholdRanges as ApproximateThresholdRanges,
@@ -325,6 +326,7 @@ from .._impl import (
     scout_compute_api_SummarizeGeo as SummarizeGeo,
     scout_compute_api_SummarizeRanges as SummarizeRanges,
     scout_compute_api_SummarizeSeries as SummarizeSeries,
+    scout_compute_api_Summation as Summation,
     scout_compute_api_TagFilter as TagFilter,
     scout_compute_api_TagFilterOperator as TagFilterOperator,
     scout_compute_api_TagFilterValidationErrorType as TagFilterValidationErrorType,
@@ -367,6 +369,7 @@ __all__ = [
     'AfterPersistenceWindow',
     'AggregateEnumSeries',
     'AggregateNumericSeries',
+    'AggregateUnderRangesSeries',
     'AllowNegativeValues',
     'ApproximateThresholdOperator',
     'ApproximateThresholdRanges',
@@ -686,6 +689,7 @@ __all__ = [
     'SummarizeGeo',
     'SummarizeRanges',
     'SummarizeSeries',
+    'Summation',
     'TagFilter',
     'TagFilterOperator',
     'TagFilterValidationErrorType',
