@@ -104,6 +104,7 @@ from .._impl import (
     scout_compute_resolved_api_RangesNode as RangesNode,
     scout_compute_resolved_api_RangesNodeVisitor as RangesNodeVisitor,
     scout_compute_resolved_api_RangesNumericAggregationNode as RangesNumericAggregationNode,
+    scout_compute_resolved_api_RangesNumericAggregationToNumericSeriesNode as RangesNumericAggregationToNumericSeriesNode,
     scout_compute_resolved_api_RawEnumSeriesNode as RawEnumSeriesNode,
     scout_compute_resolved_api_RawLogSeriesNode as RawLogSeriesNode,
     scout_compute_resolved_api_RawNumericSeriesNode as RawNumericSeriesNode,
@@ -264,6 +265,7 @@ __all__ = [
     'RangesNode',
     'RangesNodeVisitor',
     'RangesNumericAggregationNode',
+    'RangesNumericAggregationToNumericSeriesNode',
     'RawEnumSeriesNode',
     'RawLogSeriesNode',
     'RawNumericSeriesNode',
